summaryrefslogtreecommitdiffstats
path: root/libktorrent/expandablewidget.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 20:34:15 +0000
commit1c1403293485f35fd53db45aaa77a01cdd9627e7 (patch)
tree38559cd68cd4f63023fb5f6375def9db3b8b491e /libktorrent/expandablewidget.h
parent894f94545727610df22c4f73911d62d58266f695 (diff)
downloadktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.tar.gz
ktorrent-1c1403293485f35fd53db45aaa77a01cdd9627e7.zip
TQt4 port ktorrent
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktorrent@1238733 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'libktorrent/expandablewidget.h')
-rw-r--r--libktorrent/expandablewidget.h31
1 files changed, 16 insertions, 15 deletions
diff --git a/libktorrent/expandablewidget.h b/libktorrent/expandablewidget.h
index 823ce5f..070f24f 100644
--- a/libktorrent/expandablewidget.h
+++ b/libktorrent/expandablewidget.h
@@ -20,12 +20,12 @@
#ifndef KTEXPANDABLEWIDGET_H
#define KTEXPANDABLEWIDGET_H
-#include <qwidget.h>
-#include <qptrlist.h>
+#include <tqwidget.h>
+#include <tqptrlist.h>
#include <interfaces/guiinterface.h>
-class QSplitter;
-class QHBoxLayout;
+class TQSplitter;
+class TQHBoxLayout;
namespace kt
{
@@ -40,39 +40,40 @@ namespace kt
* one child widget. It allows to add more widgets separating the new widget
* and everything which was previously in the container by a separator.
*/
- class ExpandableWidget : public QWidget
+ class ExpandableWidget : public TQWidget
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Constructor, the first child must be provided.
* @param child The first child
* @param parent The parent
* @param name The name
*/
- ExpandableWidget(QWidget* child,QWidget *parent = 0, const char *name = 0);
+ ExpandableWidget(TQWidget* child,TQWidget *tqparent = 0, const char *name = 0);
virtual ~ExpandableWidget();
/**
* Expand the widget. This will ensure the proper parent child relations.
* @param w The widget
* @param pos It's position relative to the current widget
*/
- void expand(QWidget* w,Position pos);
+ void expand(TQWidget* w,Position pos);
/**
* Remove a widget. This will ensure the proper parent child relations.
* The widget w will become parentless. Note the first child will never be removed.
* @param w The widget
*/
- void remove(QWidget* w);
+ void remove(TQWidget* w);
private:
struct StackElement
{
- QWidget* w;
- QSplitter* s;
+ TQWidget* w;
+ TQSplitter* s;
Position pos;
StackElement* next;
@@ -81,7 +82,7 @@ namespace kt
};
StackElement* begin;
- QHBoxLayout* top_layout;
+ TQHBoxLayout* top_layout;
};
}
@@ -40,39 +40,40 @@ namespace kt
* Constructor, the first child must be provided.
* @param child The first child
- * @param parent The parent
+ * @param tqparent The tqparent
* @param name The name
*/
@@ -40,39 +40,40 @@ namespace kt
virtual ~ExpandableWidget();
/**
- * Expand the widget. This will ensure the proper parent child relations.
+ * Expand the widget. This will ensure the proper tqparent child relations.
* @param w The widget
* @param pos It's position relative to the current widget
@@ -40,39 +40,40 @@ namespace kt
/**
- * Remove a widget. This will ensure the proper parent child relations.
- * The widget w will become parentless. Note the first child will never be removed.
+ * Remove a widget. This will ensure the proper tqparent child relations.
+ * The widget w will become tqparentless. Note the first child will never be removed.
* @param w The widget
*/